==> apache-polaris-1.2.0-incubating.tar.gz: apache-polaris-1.2.0-incubating/runtime/service/src/test/java/org/apache/polaris/service/test/DefaultTestEnvironmentResolver.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.polaris.service.test;

import org.junit.jupiter.api.extension.ExtensionContext;

public class DefaultTestEnvironmentResolver implements TestEnvironmentResolver {

  private final int localPort = Integer.getInteger("quarkus.http.port");
  private final int localManagementPort = Integer.getInteger("quarkus.management.port");

  /** Resolves the TestEnvironment to point to the local Quarkus Application instance. */
  @Override
  public TestEnvironment resolveTestEnvironment(ExtensionContext extensionContext) {
    return new TestEnvironment(
        String.format("http://localhost:%d", localPort),
        String.format("http://localhost:%d", localManagementPort));
  }
}

==> apache-polaris-1.3.0-incubating.tar.gz: apache-polaris-1.3.0-incubating/runtime/service/src/test/java/org/apache/polaris/service/test/DefaultTestEnvironmentResolver.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.polaris.service.test;

import org.junit.jupiter.api.extension.ExtensionContext;

public class DefaultTestEnvironmentResolver implements TestEnvironmentResolver {

  private final int localPort = Integer.getInteger("quarkus.http.port");
  private final int localManagementPort = Integer.getInteger("quarkus.management.port");

  /** Resolves the TestEnvironment to point to the local Quarkus Application instance. */
  @Override
  public TestEnvironment resolveTestEnvironment(ExtensionContext extensionContext) {
    return new TestEnvironment(
        String.format("http://localhost:%d/", localPort),
        String.format("http://localhost:%d/", localManagementPort));
  }
}
